@@ -21,11 +21,13 @@
 #ifndef __GES_ENUMS_H__
 #define __GES_ENUMS_H__
 
-#include <glib-object.h>
+#include <gst/gst.h>
+#include <ges/ges-prelude.h>
 
 G_BEGIN_DECLS
 
 #define GES_TYPE_TRACK_TYPE (ges_track_type_get_type ())
+GES_API
 GType ges_track_type_get_type (void);
 
 /**
@@ -53,6 +55,7 @@ typedef enum {
 } GESTrackType;
 
 #define GES_META_FLAG_TYPE (ges_meta_flag_get_type ())
+GES_API
 GType ges_meta_flag_get_type (void);
 
 /**
@@ -222,6 +225,7 @@ typedef enum {
 #define GES_VIDEO_STANDARD_TRANSITION_TYPE_TYPE \
     (ges_video_standard_transition_type_get_type())
 
+GES_API
 GType ges_video_standard_transition_type_get_type (void);
 
 /**
@@ -239,8 +243,8 @@ typedef enum {
     GES_TEXT_VALIGN_BOTTOM,
     GES_TEXT_VALIGN_TOP,
     GES_TEXT_VALIGN_POSITION,
-    GES_TEXT_VALIGN_ABSOLUTE,
-    GES_TEXT_VALIGN_CENTER
+    GES_TEXT_VALIGN_CENTER,
+    GES_TEXT_VALIGN_ABSOLUTE
 } GESTextVAlign;
 
 #define DEFAULT_VALIGNMENT GES_TEXT_VALIGN_BASELINE
@@ -248,6 +252,7 @@ typedef enum {
 #define GES_TEXT_VALIGN_TYPE\
   (ges_text_valign_get_type ())
 
+GES_API
 GType ges_text_valign_get_type (void);
 
 /**
@@ -272,6 +277,7 @@ typedef enum {
 #define GES_TEXT_HALIGN_TYPE\
   (ges_text_halign_get_type ())
 
+GES_API
 GType ges_text_halign_get_type (void);
 
 /**
@@ -323,6 +329,7 @@ typedef enum {
 #define GES_VIDEO_TEST_PATTERN_TYPE\
   ges_video_test_pattern_get_type()
 
+GES_API
 GType ges_video_test_pattern_get_type (void);
 
 /**
@@ -346,6 +353,7 @@ typedef enum {
 #define GES_TYPE_PIPELINE_FLAGS\
   ges_pipeline_flags_get_type()
 
+GES_API
 GType ges_pipeline_flags_get_type (void);
 
 /**
@@ -386,6 +394,7 @@ typedef enum {
 
 #define GES_TYPE_EDIT_MODE ges_edit_mode_get_type()
 
+GES_API
 GType ges_edit_mode_get_type (void);
 
 /**
@@ -403,11 +412,16 @@ typedef enum {
     GES_EDGE_NONE
 } GESEdge;
 
+GES_API
+const gchar * ges_edge_name (GESEdge edge);
+
 #define GES_TYPE_EDGE ges_edge_get_type()
 
+GES_API
 GType ges_edge_get_type (void);
 
 
+GES_API
 const gchar * ges_track_type_name (GESTrackType type);
 G_END_DECLS
 
